/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2007,2008 Bull S.A.S.
 * Contact: carol@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: SimplePropertyInfo.java 1664 2008-03-09 12:18:41Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.info.mapping;

import net.jcip.annotations.NotThreadSafe;

/**
 * Represent a property with a simple value.
 * @author Loris Bouzonnet
 */
@NotThreadSafe
public final class SimplePropertyInfo {

    /**
     * The property name.
     */
    private String name;

    /**
     * The simple value.
     */
    private String value;

    public SimplePropertyInfo() {
    }

    /**
     * @return the name
     */
    public String getName() {
        return name;
    }

    /**
     * @param name the name to set
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * @return the value
     */
    public String getValue() {
        return value;
    }

    /**
     * @param value the value to set
     */
    public void setValue(final String value) {
        this.value = value;
    }

    @Override
    public boolean equals(final Object obj) {
        if(obj == null || !(obj instanceof SimplePropertyInfo)) {
            return false;
        }
        SimplePropertyInfo propertyInfo = (SimplePropertyInfo) obj;
        return name.equals(propertyInfo.name)
            && value.equals(propertyInfo.value);
    }

    @Override
    public String toString() {
        return "SimplePropertyInfo["
            + "name:" + name
            + ",value:" + value
            + "]";
    }

}
